# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import transaction_pb2 as transaction__pb2


class TransactionStub(object):
    """Transaction service defines various RPC methods for interacting with
    transactions.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetTransaction = channel.unary_unary(
                '/pactus.Transaction/GetTransaction',
                request_serializer=transaction__pb2.GetTransactionRequest.SerializeToString,
                response_deserializer=transaction__pb2.GetTransactionResponse.FromString,
                )
        self.CalculateFee = channel.unary_unary(
                '/pactus.Transaction/CalculateFee',
                request_serializer=transaction__pb2.CalculateFeeRequest.SerializeToString,
                response_deserializer=transaction__pb2.CalculateFeeResponse.FromString,
                )
        self.BroadcastTransaction = channel.unary_unary(
                '/pactus.Transaction/BroadcastTransaction',
                request_serializer=transaction__pb2.BroadcastTransactionRequest.SerializeToString,
                response_deserializer=transaction__pb2.BroadcastTransactionResponse.FromString,
                )
        self.GetRawTransferTransaction = channel.unary_unary(
                '/pactus.Transaction/GetRawTransferTransaction',
                request_serializer=transaction__pb2.GetRawTransferTransactionRequest.SerializeToString,
                response_deserializer=transaction__pb2.GetRawTransactionResponse.FromString,
                )
        self.GetRawBondTransaction = channel.unary_unary(
                '/pactus.Transaction/GetRawBondTransaction',
                request_serializer=transaction__pb2.GetRawBondTransactionRequest.SerializeToString,
                response_deserializer=transaction__pb2.GetRawTransactionResponse.FromString,
                )
        self.GetRawUnbondTransaction = channel.unary_unary(
                '/pactus.Transaction/GetRawUnbondTransaction',
                request_serializer=transaction__pb2.GetRawUnbondTransactionRequest.SerializeToString,
                response_deserializer=transaction__pb2.GetRawTransactionResponse.FromString,
                )
        self.GetRawWithdrawTransaction = channel.unary_unary(
                '/pactus.Transaction/GetRawWithdrawTransaction',
                request_serializer=transaction__pb2.GetRawWithdrawTransactionRequest.SerializeToString,
                response_deserializer=transaction__pb2.GetRawTransactionResponse.FromString,
                )


class TransactionServicer(object):
    """Transaction service defines various RPC methods for interacting with
    transactions.
    """

    def GetTransaction(self, request, context):
        """GetTransaction retrieves transaction details based on the provided request
        parameters.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CalculateFee(self, request, context):
        """CalculateFee calculates the transaction fee based on the specified amount
        and payload type.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BroadcastTransaction(self, request, context):
        """BroadcastTransaction broadcasts a signed transaction to the network.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRawTransferTransaction(self, request, context):
        """GetRawTransferTransaction retrieves raw details of a transfer transaction.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRawBondTransaction(self, request, context):
        """GetRawBondTransaction retrieves raw details of a bond transaction.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRawUnbondTransaction(self, request, context):
        """GetRawUnbondTransaction retrieves raw details of an unbond transaction.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRawWithdrawTransaction(self, request, context):
        """GetRawWithdrawTransaction retrieves raw details of a withdraw transaction.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TransactionServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransaction,
                    request_deserializer=transaction__pb2.GetTransactionRequest.FromString,
                    response_serializer=transaction__pb2.GetTransactionResponse.SerializeToString,
            ),
            'CalculateFee': grpc.unary_unary_rpc_method_handler(
                    servicer.CalculateFee,
                    request_deserializer=transaction__pb2.CalculateFeeRequest.FromString,
                    response_serializer=transaction__pb2.CalculateFeeResponse.SerializeToString,
            ),
            'BroadcastTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.BroadcastTransaction,
                    request_deserializer=transaction__pb2.BroadcastTransactionRequest.FromString,
                    response_serializer=transaction__pb2.BroadcastTransactionResponse.SerializeToString,
            ),
            'GetRawTransferTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRawTransferTransaction,
                    request_deserializer=transaction__pb2.GetRawTransferTransactionRequest.FromString,
                    response_serializer=transaction__pb2.GetRawTransactionResponse.SerializeToString,
            ),
            'GetRawBondTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRawBondTransaction,
                    request_deserializer=transaction__pb2.GetRawBondTransactionRequest.FromString,
                    response_serializer=transaction__pb2.GetRawTransactionResponse.SerializeToString,
            ),
            'GetRawUnbondTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRawUnbondTransaction,
                    request_deserializer=transaction__pb2.GetRawUnbondTransactionRequest.FromString,
                    response_serializer=transaction__pb2.GetRawTransactionResponse.SerializeToString,
            ),
            'GetRawWithdrawTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRawWithdrawTransaction,
                    request_deserializer=transaction__pb2.GetRawWithdrawTransactionRequest.FromString,
                    response_serializer=transaction__pb2.GetRawTransactionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'pactus.Transaction', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Transaction(object):
    """Transaction service defines various RPC methods for interacting with
    transactions.
    """

    @staticmethod
    def GetTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Transaction/GetTransaction',
            transaction__pb2.GetTransactionRequest.SerializeToString,
            transaction__pb2.GetTransactionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CalculateFee(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Transaction/CalculateFee',
            transaction__pb2.CalculateFeeRequest.SerializeToString,
            transaction__pb2.CalculateFeeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BroadcastTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Transaction/BroadcastTransaction',
            transaction__pb2.BroadcastTransactionRequest.SerializeToString,
            transaction__pb2.BroadcastTransactionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRawTransferTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Transaction/GetRawTransferTransaction',
            transaction__pb2.GetRawTransferTransactionRequest.SerializeToString,
            transaction__pb2.GetRawTransactionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRawBondTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Transaction/GetRawBondTransaction',
            transaction__pb2.GetRawBondTransactionRequest.SerializeToString,
            transaction__pb2.GetRawTransactionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRawUnbondTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Transaction/GetRawUnbondTransaction',
            transaction__pb2.GetRawUnbondTransactionRequest.SerializeToString,
            transaction__pb2.GetRawTransactionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRawWithdrawTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Transaction/GetRawWithdrawTransaction',
            transaction__pb2.GetRawWithdrawTransactionRequest.SerializeToString,
            transaction__pb2.GetRawTransactionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import network_pb2 as network__pb2


class NetworkStub(object):
    """Network service provides RPCs for retrieving information about the network.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetNetworkInfo = channel.unary_unary(
                '/pactus.Network/GetNetworkInfo',
                request_serializer=network__pb2.GetNetworkInfoRequest.SerializeToString,
                response_deserializer=network__pb2.GetNetworkInfoResponse.FromString,
                )
        self.GetNodeInfo = channel.unary_unary(
                '/pactus.Network/GetNodeInfo',
                request_serializer=network__pb2.GetNodeInfoRequest.SerializeToString,
                response_deserializer=network__pb2.GetNodeInfoResponse.FromString,
                )


class NetworkServicer(object):
    """Network service provides RPCs for retrieving information about the network.
    """

    def GetNetworkInfo(self, request, context):
        """GetNetworkInfo retrieves information about the overall network.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNodeInfo(self, request, context):
        """GetNodeInfo retrieves information about a specific node in the network.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NetworkServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetNetworkInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNetworkInfo,
                    request_deserializer=network__pb2.GetNetworkInfoRequest.FromString,
                    response_serializer=network__pb2.GetNetworkInfoResponse.SerializeToString,
            ),
            'GetNodeInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNodeInfo,
                    request_deserializer=network__pb2.GetNodeInfoRequest.FromString,
                    response_serializer=network__pb2.GetNodeInfoResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'pactus.Network', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Network(object):
    """Network service provides RPCs for retrieving information about the network.
    """

    @staticmethod
    def GetNetworkInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Network/GetNetworkInfo',
            network__pb2.GetNetworkInfoRequest.SerializeToString,
            network__pb2.GetNetworkInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNodeInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Network/GetNodeInfo',
            network__pb2.GetNodeInfoRequest.SerializeToString,
            network__pb2.GetNodeInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: wallet.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import transaction_pb2 as transaction__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cwallet.proto\x12\x06pactus\x1a\x11transaction.proto\"p\n\x0b\x41\x64\x64ressInfo\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x1d\n\npublic_key\x18\x02 \x01(\tR\tpublicKey\x12\x14\n\x05label\x18\x03 \x01(\tR\x05label\x12\x12\n\x04path\x18\x04 \x01(\tR\x04path\"\xa5\x01\n\x0bHistoryInfo\x12%\n\x0etransaction_id\x18\x01 \x01(\tR\rtransactionId\x12\x12\n\x04time\x18\x02 \x01(\rR\x04time\x12!\n\x0cpayload_type\x18\x03 \x01(\tR\x0bpayloadType\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\x12\x16\n\x06\x61mount\x18\x05 \x01(\x03R\x06\x61mount\"U\n\x18GetAddressHistoryRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\"S\n\x19GetAddressHistoryResponse\x12\x36\n\x0chistory_info\x18\x01 \x03(\x0b\x32\x13.pactus.HistoryInfoR\x0bhistoryInfo\"\xa1\x01\n\x14GetNewAddressRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x36\n\x0c\x61\x64\x64ress_type\x18\x02 \x01(\x0e\x32\x13.pactus.AddressTypeR\x0b\x61\x64\x64ressType\x12\x14\n\x05label\x18\x03 \x01(\tR\x05label\x12\x1a\n\x08password\x18\x04 \x01(\tR\x08password\"p\n\x15GetNewAddressResponse\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x36\n\x0c\x61\x64\x64ress_info\x18\x02 \x01(\x0b\x32\x13.pactus.AddressInfoR\x0b\x61\x64\x64ressInfo\"o\n\x14RestoreWalletRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x1a\n\x08mnemonic\x18\x02 \x01(\tR\x08mnemonic\x12\x1a\n\x08password\x18\x03 \x01(\tR\x08password\"8\n\x15RestoreWalletResponse\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\"R\n\x13\x43reateWalletRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x1a\n\x08password\x18\x04 \x01(\tR\x08password\"2\n\x14\x43reateWalletResponse\x12\x1a\n\x08mnemonic\x18\x02 \x01(\tR\x08mnemonic\"4\n\x11LoadWalletRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\"5\n\x12LoadWalletResponse\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\"6\n\x13UnloadWalletRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\"7\n\x14UnloadWalletResponse\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\";\n\x1aGetValidatorAddressRequest\x12\x1d\n\npublic_key\x18\x01 \x01(\tR\tpublicKey\"7\n\x1bGetValidatorAddressResponse\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\"\x81\x01\n\x19SignRawTransactionRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\'\n\x0fraw_transaction\x18\x02 \x01(\tR\x0erawTransaction\x12\x1a\n\x08password\x18\x03 \x01(\tR\x08password\"y\n\x1aSignRawTransactionResponse\x12%\n\x0etransaction_id\x18\x01 \x01(\tR\rtransactionId\x12\x34\n\x16signed_raw_transaction\x18\x02 \x01(\tR\x14signedRawTransaction\"9\n\x16GetTotalBalanceRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\"_\n\x17GetTotalBalanceResponse\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12#\n\rtotal_balance\x18\x02 \x01(\x03R\x0ctotalBalance\"\x85\x01\n\x12SignMessageRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x1a\n\x08password\x18\x02 \x01(\tR\x08password\x12\x18\n\x07\x61\x64\x64ress\x18\x03 \x01(\tR\x07\x61\x64\x64ress\x12\x18\n\x07message\x18\x04 \x01(\tR\x07message\"3\n\x13SignMessageResponse\x12\x1c\n\tsignature\x18\x01 \x01(\tR\tsignature\"7\n\x14GetTotalStakeRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\"Y\n\x15GetTotalStakeResponse\x12\x1f\n\x0btotal_stake\x18\x01 \x01(\x03R\ntotalStake\x12\x1f\n\x0bwallet_name\x18\x02 \x01(\tR\nwalletName\"R\n\x15GetAddressInfoRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\"\x9c\x01\n\x16GetAddressInfoResponse\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x14\n\x05label\x18\x02 \x01(\tR\x05label\x12\x1d\n\npublic_key\x18\x03 \x01(\tR\tpublicKey\x12\x12\n\x04path\x18\x04 \x01(\tR\x04path\x12\x1f\n\x0bwallet_name\x18\x05 \x01(\tR\nwalletName\"~\n\x0fSetLabelRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x1a\n\x08password\x18\x03 \x01(\tR\x08password\x12\x18\n\x07\x61\x64\x64ress\x18\x04 \x01(\tR\x07\x61\x64\x64ress\x12\x14\n\x05label\x18\x05 \x01(\tR\x05label\"\x12\n\x10SetLabelResponse\"\x13\n\x11ListWalletRequest\".\n\x12ListWalletResponse\x12\x18\n\x07wallets\x18\x01 \x03(\tR\x07wallets\"7\n\x14GetWalletInfoRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\"\xbd\x01\n\x15GetWalletInfoResponse\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x18\n\x07version\x18\x02 \x01(\x03R\x07version\x12\x18\n\x07network\x18\x03 \x01(\tR\x07network\x12\x1c\n\tencrypted\x18\x04 \x01(\x08R\tencrypted\x12\x12\n\x04uuid\x18\x05 \x01(\tR\x04uuid\x12\x1d\n\ncreated_at\x18\x06 \x01(\x03R\tcreatedAt\"5\n\x12ListAddressRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\">\n\x13ListAddressResponse\x12\'\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x13.pactus.AddressInfoR\x04\x64\x61ta*\x84\x01\n\x0b\x41\x64\x64ressType\x12\x19\n\x15\x41\x44\x44RESS_TYPE_TREASURY\x10\x00\x12\x1a\n\x16\x41\x44\x44RESS_TYPE_VALIDATOR\x10\x01\x12\x1c\n\x18\x41\x44\x44RESS_TYPE_BLS_ACCOUNT\x10\x02\x12 \n\x1c\x41\x44\x44RESS_TYPE_ED25519_ACCOUNT\x10\x03\x32\xf2\t\n\x06Wallet\x12I\n\x0c\x43reateWallet\x12\x1b.pactus.CreateWalletRequest\x1a\x1c.pactus.CreateWalletResponse\x12L\n\rRestoreWallet\x12\x1c.pactus.RestoreWalletRequest\x1a\x1d.pactus.RestoreWalletResponse\x12\x43\n\nLoadWallet\x12\x19.pactus.LoadWalletRequest\x1a\x1a.pactus.LoadWalletResponse\x12I\n\x0cUnloadWallet\x12\x1b.pactus.UnloadWalletRequest\x1a\x1c.pactus.UnloadWalletResponse\x12R\n\x0fGetTotalBalance\x12\x1e.pactus.GetTotalBalanceRequest\x1a\x1f.pactus.GetTotalBalanceResponse\x12[\n\x12SignRawTransaction\x12!.pactus.SignRawTransactionRequest\x1a\".pactus.SignRawTransactionResponse\x12^\n\x13GetValidatorAddress\x12\".pactus.GetValidatorAddressRequest\x1a#.pactus.GetValidatorAddressResponse\x12L\n\rGetNewAddress\x12\x1c.pactus.GetNewAddressRequest\x1a\x1d.pactus.GetNewAddressResponse\x12X\n\x11GetAddressHistory\x12 .pactus.GetAddressHistoryRequest\x1a!.pactus.GetAddressHistoryResponse\x12\x46\n\x0bSignMessage\x12\x1a.pactus.SignMessageRequest\x1a\x1b.pactus.SignMessageResponse\x12L\n\rGetTotalStake\x12\x1c.pactus.GetTotalStakeRequest\x1a\x1d.pactus.GetTotalStakeResponse\x12O\n\x0eGetAddressInfo\x12\x1d.pactus.GetAddressInfoRequest\x1a\x1e.pactus.GetAddressInfoResponse\x12\x44\n\x0fSetAddressLabel\x12\x17.pactus.SetLabelRequest\x1a\x18.pactus.SetLabelResponse\x12\x43\n\nListWallet\x12\x19.pactus.ListWalletRequest\x1a\x1a.pactus.ListWalletResponse\x12L\n\rGetWalletInfo\x12\x1c.pactus.GetWalletInfoRequest\x1a\x1d.pactus.GetWalletInfoResponse\x12\x46\n\x0bListAddress\x12\x1a.pactus.ListAddressRequest\x1a\x1b.pactus.ListAddressResponseBA\n\rpactus.walletZ0github.com/pactus-project/pactus/www/grpc/pactusb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'wallet_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\rpactus.walletZ0github.com/pactus-project/pactus/www/grpc/pactus'
  _ADDRESSTYPE._serialized_start=2999
  _ADDRESSTYPE._serialized_end=3131
  _ADDRESSINFO._serialized_start=43
  _ADDRESSINFO._serialized_end=155
  _HISTORYINFO._serialized_start=158
  _HISTORYINFO._serialized_end=323
  _GETADDRESSHISTORYREQUEST._serialized_start=325
  _GETADDRESSHISTORYREQUEST._serialized_end=410
  _GETADDRESSHISTORYRESPONSE._serialized_start=412
  _GETADDRESSHISTORYRESPONSE._serialized_end=495
  _GETNEWADDRESSREQUEST._serialized_start=498
  _GETNEWADDRESSREQUEST._serialized_end=659
  _GETNEWADDRESSRESPONSE._serialized_start=661
  _GETNEWADDRESSRESPONSE._serialized_end=773
  _RESTOREWALLETREQUEST._serialized_start=775
  _RESTOREWALLETREQUEST._serialized_end=886
  _RESTOREWALLETRESPONSE._serialized_start=888
  _RESTOREWALLETRESPONSE._serialized_end=944
  _CREATEWALLETREQUEST._serialized_start=946
  _CREATEWALLETREQUEST._serialized_end=1028
  _CREATEWALLETRESPONSE._serialized_start=1030
  _CREATEWALLETRESPONSE._serialized_end=1080
  _LOADWALLETREQUEST._serialized_start=1082
  _LOADWALLETREQUEST._serialized_end=1134
  _LOADWALLETRESPONSE._serialized_start=1136
  _LOADWALLETRESPONSE._serialized_end=1189
  _UNLOADWALLETREQUEST._serialized_start=1191
  _UNLOADWALLETREQUEST._serialized_end=1245
  _UNLOADWALLETRESPONSE._serialized_start=1247
  _UNLOADWALLETRESPONSE._serialized_end=1302
  _GETVALIDATORADDRESSREQUEST._serialized_start=1304
  _GETVALIDATORADDRESSREQUEST._serialized_end=1363
  _GETVALIDATORADDRESSRESPONSE._serialized_start=1365
  _GETVALIDATORADDRESSRESPONSE._serialized_end=1420
  _SIGNRAWTRANSACTIONREQUEST._serialized_start=1423
  _SIGNRAWTRANSACTIONREQUEST._serialized_end=1552
  _SIGNRAWTRANSACTIONRESPONSE._serialized_start=1554
  _SIGNRAWTRANSACTIONRESPONSE._serialized_end=1675
  _GETTOTALBALANCEREQUEST._serialized_start=1677
  _GETTOTALBALANCEREQUEST._serialized_end=1734
  _GETTOTALBALANCERESPONSE._serialized_start=1736
  _GETTOTALBALANCERESPONSE._serialized_end=1831
  _SIGNMESSAGEREQUEST._serialized_start=1834
  _SIGNMESSAGEREQUEST._serialized_end=1967
  _SIGNMESSAGERESPONSE._serialized_start=1969
  _SIGNMESSAGERESPONSE._serialized_end=2020
  _GETTOTALSTAKEREQUEST._serialized_start=2022
  _GETTOTALSTAKEREQUEST._serialized_end=2077
  _GETTOTALSTAKERESPONSE._serialized_start=2079
  _GETTOTALSTAKERESPONSE._serialized_end=2168
  _GETADDRESSINFOREQUEST._serialized_start=2170
  _GETADDRESSINFOREQUEST._serialized_end=2252
  _GETADDRESSINFORESPONSE._serialized_start=2255
  _GETADDRESSINFORESPONSE._serialized_end=2411
  _SETLABELREQUEST._serialized_start=2413
  _SETLABELREQUEST._serialized_end=2539
  _SETLABELRESPONSE._serialized_start=2541
  _SETLABELRESPONSE._serialized_end=2559
  _LISTWALLETREQUEST._serialized_start=2561
  _LISTWALLETREQUEST._serialized_end=2580
  _LISTWALLETRESPONSE._serialized_start=2582
  _LISTWALLETRESPONSE._serialized_end=2628
  _GETWALLETINFOREQUEST._serialized_start=2630
  _GETWALLETINFOREQUEST._serialized_end=2685
  _GETWALLETINFORESPONSE._serialized_start=2688
  _GETWALLETINFORESPONSE._serialized_end=2877
  _LISTADDRESSREQUEST._serialized_start=2879
  _LISTADDRESSREQUEST._serialized_end=2932
  _LISTADDRESSRESPONSE._serialized_start=2934
  _LISTADDRESSRESPONSE._serialized_end=2996
  _WALLET._serialized_start=3134
  _WALLET._serialized_end=4400
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: utils.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0butils.proto\x12\x06pactus\"]\n SignMessageWithPrivateKeyRequest\x12\x1f\n\x0bprivate_key\x18\x01 \x01(\tR\nprivateKey\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\"A\n!SignMessageWithPrivateKeyResponse\x12\x1c\n\tsignature\x18\x01 \x01(\tR\tsignature\"m\n\x14VerifyMessageRequest\x12\x18\n\x07message\x18\x01 \x01(\tR\x07message\x12\x1c\n\tsignature\x18\x02 \x01(\tR\tsignature\x12\x1d\n\npublic_key\x18\x03 \x01(\tR\tpublicKey\"2\n\x15VerifyMessageResponse\x12\x19\n\x08is_valid\x18\x01 \x01(\x08R\x07isValid\"A\n\x1e\x42LSPublicKeyAggregationRequest\x12\x1f\n\x0bpublic_keys\x18\x01 \x03(\tR\npublicKeys\"Z\n\x1f\x42LSPublicKeyAggregationResponse\x12\x1d\n\npublic_key\x18\x01 \x01(\tR\tpublicKey\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\"@\n\x1e\x42LSSignatureAggregationRequest\x12\x1e\n\nsignatures\x18\x01 \x03(\tR\nsignatures\"?\n\x1f\x42LSSignatureAggregationResponse\x12\x1c\n\tsignature\x18\x01 \x01(\tR\tsignature2\x9f\x03\n\x05Utils\x12p\n\x19SignMessageWithPrivateKey\x12(.pactus.SignMessageWithPrivateKeyRequest\x1a).pactus.SignMessageWithPrivateKeyResponse\x12L\n\rVerifyMessage\x12\x1c.pactus.VerifyMessageRequest\x1a\x1d.pactus.VerifyMessageResponse\x12j\n\x17\x42LSPublicKeyAggregation\x12&.pactus.BLSPublicKeyAggregationRequest\x1a\'.pactus.BLSPublicKeyAggregationResponse\x12j\n\x17\x42LSSignatureAggregation\x12&.pactus.BLSSignatureAggregationRequest\x1a\'.pactus.BLSSignatureAggregationResponseB@\n\x0cpactus.utilsZ0github.com/pactus-project/pactus/www/grpc/pactusb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'utils_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\014pactus.utilsZ0github.com/pactus-project/pactus/www/grpc/pactus'
  _SIGNMESSAGEWITHPRIVATEKEYREQUEST._serialized_start=23
  _SIGNMESSAGEWITHPRIVATEKEYREQUEST._serialized_end=116
  _SIGNMESSAGEWITHPRIVATEKEYRESPONSE._serialized_start=118
  _SIGNMESSAGEWITHPRIVATEKEYRESPONSE._serialized_end=183
  _VERIFYMESSAGEREQUEST._serialized_start=185
  _VERIFYMESSAGEREQUEST._serialized_end=294
  _VERIFYMESSAGERESPONSE._serialized_start=296
  _VERIFYMESSAGERESPONSE._serialized_end=346
  _BLSPUBLICKEYAGGREGATIONREQUEST._serialized_start=348
  _BLSPUBLICKEYAGGREGATIONREQUEST._serialized_end=413
  _BLSPUBLICKEYAGGREGATIONRESPONSE._serialized_start=415
  _BLSPUBLICKEYAGGREGATIONRESPONSE._serialized_end=505
  _BLSSIGNATUREAGGREGATIONREQUEST._serialized_start=507
  _BLSSIGNATUREAGGREGATIONREQUEST._serialized_end=571
  _BLSSIGNATUREAGGREGATIONRESPONSE._serialized_start=573
  _BLSSIGNATUREAGGREGATIONRESPONSE._serialized_end=636
  _UTILS._serialized_start=639
  _UTILS._serialized_end=1054
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import utils_pb2 as utils__pb2


class UtilsStub(object):
    """Utils service defines RPC methods for utility functions such as message
    signing and verification.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SignMessageWithPrivateKey = channel.unary_unary(
                '/pactus.Utils/SignMessageWithPrivateKey',
                request_serializer=utils__pb2.SignMessageWithPrivateKeyRequest.SerializeToString,
                response_deserializer=utils__pb2.SignMessageWithPrivateKeyResponse.FromString,
                )
        self.VerifyMessage = channel.unary_unary(
                '/pactus.Utils/VerifyMessage',
                request_serializer=utils__pb2.VerifyMessageRequest.SerializeToString,
                response_deserializer=utils__pb2.VerifyMessageResponse.FromString,
                )
        self.BLSPublicKeyAggregation = channel.unary_unary(
                '/pactus.Utils/BLSPublicKeyAggregation',
                request_serializer=utils__pb2.BLSPublicKeyAggregationRequest.SerializeToString,
                response_deserializer=utils__pb2.BLSPublicKeyAggregationResponse.FromString,
                )
        self.BLSSignatureAggregation = channel.unary_unary(
                '/pactus.Utils/BLSSignatureAggregation',
                request_serializer=utils__pb2.BLSSignatureAggregationRequest.SerializeToString,
                response_deserializer=utils__pb2.BLSSignatureAggregationResponse.FromString,
                )


class UtilsServicer(object):
    """Utils service defines RPC methods for utility functions such as message
    signing and verification.
    """

    def SignMessageWithPrivateKey(self, request, context):
        """SignMessageWithPrivateKey signs message with provided private key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VerifyMessage(self, request, context):
        """VerifyMessage verifies signature with public key and message.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BLSPublicKeyAggregation(self, request, context):
        """BLSPublicKeyAggregation aggregates bls public keys.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BLSSignatureAggregation(self, request, context):
        """BLSSignatureAggregation aggregates bls signatures.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UtilsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SignMessageWithPrivateKey': grpc.unary_unary_rpc_method_handler(
                    servicer.SignMessageWithPrivateKey,
                    request_deserializer=utils__pb2.SignMessageWithPrivateKeyRequest.FromString,
                    response_serializer=utils__pb2.SignMessageWithPrivateKeyResponse.SerializeToString,
            ),
            'VerifyMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.VerifyMessage,
                    request_deserializer=utils__pb2.VerifyMessageRequest.FromString,
                    response_serializer=utils__pb2.VerifyMessageResponse.SerializeToString,
            ),
            'BLSPublicKeyAggregation': grpc.unary_unary_rpc_method_handler(
                    servicer.BLSPublicKeyAggregation,
                    request_deserializer=utils__pb2.BLSPublicKeyAggregationRequest.FromString,
                    response_serializer=utils__pb2.BLSPublicKeyAggregationResponse.SerializeToString,
            ),
            'BLSSignatureAggregation': grpc.unary_unary_rpc_method_handler(
                    servicer.BLSSignatureAggregation,
                    request_deserializer=utils__pb2.BLSSignatureAggregationRequest.FromString,
                    response_serializer=utils__pb2.BLSSignatureAggregationResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'pactus.Utils', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Utils(object):
    """Utils service defines RPC methods for utility functions such as message
    signing and verification.
    """

    @staticmethod
    def SignMessageWithPrivateKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Utils/SignMessageWithPrivateKey',
            utils__pb2.SignMessageWithPrivateKeyRequest.SerializeToString,
            utils__pb2.SignMessageWithPrivateKeyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def VerifyMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Utils/VerifyMessage',
            utils__pb2.VerifyMessageRequest.SerializeToString,
            utils__pb2.VerifyMessageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BLSPublicKeyAggregation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Utils/BLSPublicKeyAggregation',
            utils__pb2.BLSPublicKeyAggregationRequest.SerializeToString,
            utils__pb2.BLSPublicKeyAggregationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BLSSignatureAggregation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Utils/BLSSignatureAggregation',
            utils__pb2.BLSSignatureAggregationRequest.SerializeToString,
            utils__pb2.BLSSignatureAggregationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: network.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rnetwork.proto\x12\x06pactus\">\n\x15GetNetworkInfoRequest\x12%\n\x0eonly_connected\x18\x01 \x01(\x08R\ronlyConnected\"\xdf\x01\n\x16GetNetworkInfoResponse\x12!\n\x0cnetwork_name\x18\x01 \x01(\tR\x0bnetworkName\x12\x32\n\x15\x63onnected_peers_count\x18\x02 \x01(\rR\x13\x63onnectedPeersCount\x12\x39\n\x0f\x63onnected_peers\x18\x03 \x03(\x0b\x32\x10.pactus.PeerInfoR\x0e\x63onnectedPeers\x12\x33\n\x0bmetric_info\x18\x04 \x01(\x0b\x32\x12.pactus.MetricInfoR\nmetricInfo\"\x14\n\x12GetNodeInfoRequest\"\xc8\x03\n\x13GetNodeInfoResponse\x12\x18\n\x07moniker\x18\x01 \x01(\tR\x07moniker\x12\x14\n\x05\x61gent\x18\x02 \x01(\tR\x05\x61gent\x12\x17\n\x07peer_id\x18\x03 \x01(\tR\x06peerId\x12\x1d\n\nstarted_at\x18\x04 \x01(\x04R\tstartedAt\x12\"\n\x0creachability\x18\x05 \x01(\tR\x0creachability\x12\x1a\n\x08services\x18\x06 \x01(\x05R\x08services\x12%\n\x0eservices_names\x18\x07 \x01(\tR\rservicesNames\x12\x1f\n\x0blocal_addrs\x18\x08 \x03(\tR\nlocalAddrs\x12\x1c\n\tprotocols\x18\t \x03(\tR\tprotocols\x12!\n\x0c\x63lock_offset\x18\r \x01(\x01R\x0b\x63lockOffset\x12?\n\x0f\x63onnection_info\x18\x0e \x01(\x0b\x32\x16.pactus.ConnectionInfoR\x0e\x63onnectionInfo\x12?\n\x0ezmq_publishers\x18\x0f \x03(\x0b\x32\x18.pactus.ZMQPublisherInfoR\rzmqPublishers\"T\n\x10ZMQPublisherInfo\x12\x14\n\x05topic\x18\x01 \x01(\tR\x05topic\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\x12\x10\n\x03hwm\x18\x03 \x01(\x05R\x03hwm\"\xc2\x04\n\x08PeerInfo\x12\x16\n\x06status\x18\x01 \x01(\x05R\x06status\x12\x18\n\x07moniker\x18\x02 \x01(\tR\x07moniker\x12\x14\n\x05\x61gent\x18\x03 \x01(\tR\x05\x61gent\x12\x17\n\x07peer_id\x18\x04 \x01(\tR\x06peerId\x12%\n\x0e\x63onsensus_keys\x18\x05 \x03(\tR\rconsensusKeys\x12/\n\x13\x63onsensus_addresses\x18\x06 \x03(\tR\x12\x63onsensusAddresses\x12\x1a\n\x08services\x18\x07 \x01(\rR\x08services\x12&\n\x0flast_block_hash\x18\x08 \x01(\tR\rlastBlockHash\x12\x16\n\x06height\x18\t \x01(\rR\x06height\x12\x1b\n\tlast_sent\x18\n \x01(\x03R\x08lastSent\x12#\n\rlast_received\x18\x0b \x01(\x03R\x0clastReceived\x12\x18\n\x07\x61\x64\x64ress\x18\x0c \x01(\tR\x07\x61\x64\x64ress\x12\x1c\n\tdirection\x18\r \x01(\tR\tdirection\x12\x1c\n\tprotocols\x18\x0e \x03(\tR\tprotocols\x12%\n\x0etotal_sessions\x18\x0f \x01(\x05R\rtotalSessions\x12-\n\x12\x63ompleted_sessions\x18\x10 \x01(\x05R\x11\x63ompletedSessions\x12\x33\n\x0bmetric_info\x18\x11 \x01(\x0b\x32\x12.pactus.MetricInfoR\nmetricInfo\"\x96\x01\n\x0e\x43onnectionInfo\x12 \n\x0b\x63onnections\x18\x01 \x01(\x04R\x0b\x63onnections\x12/\n\x13inbound_connections\x18\x02 \x01(\x04R\x12inboundConnections\x12\x31\n\x14outbound_connections\x18\x03 \x01(\x04R\x13outboundConnections\"\xfb\x03\n\nMetricInfo\x12\x37\n\x0cTotalInvalid\x18\x01 \x01(\x0b\x32\x13.pactus.CounterInfoR\x0cTotalInvalid\x12\x31\n\tTotalSent\x18\x02 \x01(\x0b\x32\x13.pactus.CounterInfoR\tTotalSent\x12\x39\n\rTotalReceived\x18\x03 \x01(\x0b\x32\x13.pactus.CounterInfoR\rTotalReceived\x12\x45\n\x0bMessageSent\x18\x04 \x03(\x0b\x32#.pactus.MetricInfo.MessageSentEntryR\x0bMessageSent\x12Q\n\x0fMessageReceived\x18\x05 \x03(\x0b\x32\'.pactus.MetricInfo.MessageReceivedEntryR\x0fMessageReceived\x1aS\n\x10MessageSentEntry\x12\x10\n\x03key\x18\x01 \x01(\x05R\x03key\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x13.pactus.CounterInfoR\x05value:\x02\x38\x01\x1aW\n\x14MessageReceivedEntry\x12\x10\n\x03key\x18\x01 \x01(\x05R\x03key\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x13.pactus.CounterInfoR\x05value:\x02\x38\x01\"=\n\x0b\x43ounterInfo\x12\x14\n\x05\x42ytes\x18\x01 \x01(\x04R\x05\x42ytes\x12\x18\n\x07\x42undles\x18\x02 \x01(\x04R\x07\x42undles2\xa2\x01\n\x07Network\x12O\n\x0eGetNetworkInfo\x12\x1d.pactus.GetNetworkInfoRequest\x1a\x1e.pactus.GetNetworkInfoResponse\x12\x46\n\x0bGetNodeInfo\x12\x1a.pactus.GetNodeInfoRequest\x1a\x1b.pactus.GetNodeInfoResponseBB\n\x0epactus.networkZ0github.com/pactus-project/pactus/www/grpc/pactusb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'network_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016pactus.networkZ0github.com/pactus-project/pactus/www/grpc/pactus'
  _METRICINFO_MESSAGESENTENTRY._options = None
  _METRICINFO_MESSAGESENTENTRY._serialized_options = b'8\001'
  _METRICINFO_MESSAGERECEIVEDENTRY._options = None
  _METRICINFO_MESSAGERECEIVEDENTRY._serialized_options = b'8\001'
  _GETNETWORKINFOREQUEST._serialized_start=25
  _GETNETWORKINFOREQUEST._serialized_end=87
  _GETNETWORKINFORESPONSE._serialized_start=90
  _GETNETWORKINFORESPONSE._serialized_end=313
  _GETNODEINFOREQUEST._serialized_start=315
  _GETNODEINFOREQUEST._serialized_end=335
  _GETNODEINFORESPONSE._serialized_start=338
  _GETNODEINFORESPONSE._serialized_end=794
  _ZMQPUBLISHERINFO._serialized_start=796
  _ZMQPUBLISHERINFO._serialized_end=880
  _PEERINFO._serialized_start=883
  _PEERINFO._serialized_end=1461
  _CONNECTIONINFO._serialized_start=1464
  _CONNECTIONINFO._serialized_end=1614
  _METRICINFO._serialized_start=1617
  _METRICINFO._serialized_end=2124
  _METRICINFO_MESSAGESENTENTRY._serialized_start=1952
  _METRICINFO_MESSAGESENTENTRY._serialized_end=2035
  _METRICINFO_MESSAGERECEIVEDENTRY._serialized_start=2037
  _METRICINFO_MESSAGERECEIVEDENTRY._serialized_end=2124
  _COUNTERINFO._serialized_start=2126
  _COUNTERINFO._serialized_end=2187
  _NETWORK._serialized_start=2190
  _NETWORK._serialized_end=2352
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import wallet_pb2 as wallet__pb2


class WalletStub(object):
    """Define the Wallet service with various RPC methods for wallet management.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateWallet = channel.unary_unary(
                '/pactus.Wallet/CreateWallet',
                request_serializer=wallet__pb2.CreateWalletRequest.SerializeToString,
                response_deserializer=wallet__pb2.CreateWalletResponse.FromString,
                )
        self.RestoreWallet = channel.unary_unary(
                '/pactus.Wallet/RestoreWallet',
                request_serializer=wallet__pb2.RestoreWalletRequest.SerializeToString,
                response_deserializer=wallet__pb2.RestoreWalletResponse.FromString,
                )
        self.LoadWallet = channel.unary_unary(
                '/pactus.Wallet/LoadWallet',
                request_serializer=wallet__pb2.LoadWalletRequest.SerializeToString,
                response_deserializer=wallet__pb2.LoadWalletResponse.FromString,
                )
        self.UnloadWallet = channel.unary_unary(
                '/pactus.Wallet/UnloadWallet',
                request_serializer=wallet__pb2.UnloadWalletRequest.SerializeToString,
                response_deserializer=wallet__pb2.UnloadWalletResponse.FromString,
                )
        self.GetTotalBalance = channel.unary_unary(
                '/pactus.Wallet/GetTotalBalance',
                request_serializer=wallet__pb2.GetTotalBalanceRequest.SerializeToString,
                response_deserializer=wallet__pb2.GetTotalBalanceResponse.FromString,
                )
        self.SignRawTransaction = channel.unary_unary(
                '/pactus.Wallet/SignRawTransaction',
                request_serializer=wallet__pb2.SignRawTransactionRequest.SerializeToString,
                response_deserializer=wallet__pb2.SignRawTransactionResponse.FromString,
                )
        self.GetValidatorAddress = channel.unary_unary(
                '/pactus.Wallet/GetValidatorAddress',
                request_serializer=wallet__pb2.GetValidatorAddressRequest.SerializeToString,
                response_deserializer=wallet__pb2.GetValidatorAddressResponse.FromString,
                )
        self.GetNewAddress = channel.unary_unary(
                '/pactus.Wallet/GetNewAddress',
                request_serializer=wallet__pb2.GetNewAddressRequest.SerializeToString,
                response_deserializer=wallet__pb2.GetNewAddressResponse.FromString,
                )
        self.GetAddressHistory = channel.unary_unary(
                '/pactus.Wallet/GetAddressHistory',
                request_serializer=wallet__pb2.GetAddressHistoryRequest.SerializeToString,
                response_deserializer=wallet__pb2.GetAddressHistoryResponse.FromString,
                )
        self.SignMessage = channel.unary_unary(
                '/pactus.Wallet/SignMessage',
                request_serializer=wallet__pb2.SignMessageRequest.SerializeToString,
                response_deserializer=wallet__pb2.SignMessageResponse.FromString,
                )
        self.GetTotalStake = channel.unary_unary(
                '/pactus.Wallet/GetTotalStake',
                request_serializer=wallet__pb2.GetTotalStakeRequest.SerializeToString,
                response_deserializer=wallet__pb2.GetTotalStakeResponse.FromString,
                )
        self.GetAddressInfo = channel.unary_unary(
                '/pactus.Wallet/GetAddressInfo',
                request_serializer=wallet__pb2.GetAddressInfoRequest.SerializeToString,
                response_deserializer=wallet__pb2.GetAddressInfoResponse.FromString,
                )
        self.SetAddressLabel = channel.unary_unary(
                '/pactus.Wallet/SetAddressLabel',
                request_serializer=wallet__pb2.SetLabelRequest.SerializeToString,
                response_deserializer=wallet__pb2.SetLabelResponse.FromString,
                )
        self.ListWallet = channel.unary_unary(
                '/pactus.Wallet/ListWallet',
                request_serializer=wallet__pb2.ListWalletRequest.SerializeToString,
                response_deserializer=wallet__pb2.ListWalletResponse.FromString,
                )
        self.GetWalletInfo = channel.unary_unary(
                '/pactus.Wallet/GetWalletInfo',
                request_serializer=wallet__pb2.GetWalletInfoRequest.SerializeToString,
                response_deserializer=wallet__pb2.GetWalletInfoResponse.FromString,
                )
        self.ListAddress = channel.unary_unary(
                '/pactus.Wallet/ListAddress',
                request_serializer=wallet__pb2.ListAddressRequest.SerializeToString,
                response_deserializer=wallet__pb2.ListAddressResponse.FromString,
                )


class WalletServicer(object):
    """Define the Wallet service with various RPC methods for wallet management.
    """

    def CreateWallet(self, request, context):
        """CreateWallet creates a new wallet with the specified parameters.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RestoreWallet(self, request, context):
        """RestoreWallet restores an existing wallet with the given mnemonic.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LoadWallet(self, request, context):
        """LoadWallet loads an existing wallet with the given name.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnloadWallet(self, request, context):
        """UnloadWallet unloads a currently loaded wallet with the specified name.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTotalBalance(self, request, context):
        """GetTotalBalance returns the total available balance of the wallet.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SignRawTransaction(self, request, context):
        """SignRawTransaction signs a raw transaction for a specified wallet.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetValidatorAddress(self, request, context):
        """GetValidatorAddress retrieves the validator address associated with a
        public key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNewAddress(self, request, context):
        """GetNewAddress generates a new address for the specified wallet.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAddressHistory(self, request, context):
        """GetAddressHistory retrieves the transaction history of an address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SignMessage(self, request, context):
        """SignMessage signs an arbitrary message.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTotalStake(self, request, context):
        """GetTotalStake return total stake of wallet.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAddressInfo(self, request, context):
        """GetAddressInfo return address information.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAddressLabel(self, request, context):
        """SetAddressLabel set label for given address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListWallet(self, request, context):
        """ListWallet return list wallet name.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWalletInfo(self, request, context):
        """GetWalletInfo return wallet information.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAddress(self, request, context):
        """ListAddress return list address in wallet.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WalletServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateWallet': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateWallet,
                    request_deserializer=wallet__pb2.CreateWalletRequest.FromString,
                    response_serializer=wallet__pb2.CreateWalletResponse.SerializeToString,
            ),
            'RestoreWallet': grpc.unary_unary_rpc_method_handler(
                    servicer.RestoreWallet,
                    request_deserializer=wallet__pb2.RestoreWalletRequest.FromString,
                    response_serializer=wallet__pb2.RestoreWalletResponse.SerializeToString,
            ),
            'LoadWallet': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadWallet,
                    request_deserializer=wallet__pb2.LoadWalletRequest.FromString,
                    response_serializer=wallet__pb2.LoadWalletResponse.SerializeToString,
            ),
            'UnloadWallet': grpc.unary_unary_rpc_method_handler(
                    servicer.UnloadWallet,
                    request_deserializer=wallet__pb2.UnloadWalletRequest.FromString,
                    response_serializer=wallet__pb2.UnloadWalletResponse.SerializeToString,
            ),
            'GetTotalBalance': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTotalBalance,
                    request_deserializer=wallet__pb2.GetTotalBalanceRequest.FromString,
                    response_serializer=wallet__pb2.GetTotalBalanceResponse.SerializeToString,
            ),
            'SignRawTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.SignRawTransaction,
                    request_deserializer=wallet__pb2.SignRawTransactionRequest.FromString,
                    response_serializer=wallet__pb2.SignRawTransactionResponse.SerializeToString,
            ),
            'GetValidatorAddress': grpc.unary_unary_rpc_method_handler(
                    servicer.GetValidatorAddress,
                    request_deserializer=wallet__pb2.GetValidatorAddressRequest.FromString,
                    response_serializer=wallet__pb2.GetValidatorAddressResponse.SerializeToString,
            ),
            'GetNewAddress': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNewAddress,
                    request_deserializer=wallet__pb2.GetNewAddressRequest.FromString,
                    response_serializer=wallet__pb2.GetNewAddressResponse.SerializeToString,
            ),
            'GetAddressHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAddressHistory,
                    request_deserializer=wallet__pb2.GetAddressHistoryRequest.FromString,
                    response_serializer=wallet__pb2.GetAddressHistoryResponse.SerializeToString,
            ),
            'SignMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.SignMessage,
                    request_deserializer=wallet__pb2.SignMessageRequest.FromString,
                    response_serializer=wallet__pb2.SignMessageResponse.SerializeToString,
            ),
            'GetTotalStake': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTotalStake,
                    request_deserializer=wallet__pb2.GetTotalStakeRequest.FromString,
                    response_serializer=wallet__pb2.GetTotalStakeResponse.SerializeToString,
            ),
            'GetAddressInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAddressInfo,
                    request_deserializer=wallet__pb2.GetAddressInfoRequest.FromString,
                    response_serializer=wallet__pb2.GetAddressInfoResponse.SerializeToString,
            ),
            'SetAddressLabel': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAddressLabel,
                    request_deserializer=wallet__pb2.SetLabelRequest.FromString,
                    response_serializer=wallet__pb2.SetLabelResponse.SerializeToString,
            ),
            'ListWallet': grpc.unary_unary_rpc_method_handler(
                    servicer.ListWallet,
                    request_deserializer=wallet__pb2.ListWalletRequest.FromString,
                    response_serializer=wallet__pb2.ListWalletResponse.SerializeToString,
            ),
            'GetWalletInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWalletInfo,
                    request_deserializer=wallet__pb2.GetWalletInfoRequest.FromString,
                    response_serializer=wallet__pb2.GetWalletInfoResponse.SerializeToString,
            ),
            'ListAddress': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAddress,
                    request_deserializer=wallet__pb2.ListAddressRequest.FromString,
                    response_serializer=wallet__pb2.ListAddressResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'pactus.Wallet', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Wallet(object):
    """Define the Wallet service with various RPC methods for wallet management.
    """

    @staticmethod
    def CreateWallet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Wallet/CreateWallet',
            wallet__pb2.CreateWalletRequest.SerializeToString,
            wallet__pb2.CreateWalletResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RestoreWallet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Wallet/RestoreWallet',
            wallet__pb2.RestoreWalletRequest.SerializeToString,
            wallet__pb2.RestoreWalletResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LoadWallet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Wallet/LoadWallet',
            wallet__pb2.LoadWalletRequest.SerializeToString,
            wallet__pb2.LoadWalletResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnloadWallet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Wallet/UnloadWallet',
            wallet__pb2.UnloadWalletRequest.SerializeToString,
            wallet__pb2.UnloadWalletResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTotalBalance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Wallet/GetTotalBalance',
            wallet__pb2.GetTotalBalanceRequest.SerializeToString,
            wallet__pb2.GetTotalBalanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SignRawTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Wallet/SignRawTransaction',
            wallet__pb2.SignRawTransactionRequest.SerializeToString,
            wallet__pb2.SignRawTransactionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetValidatorAddress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Wallet/GetValidatorAddress',
            wallet__pb2.GetValidatorAddressRequest.SerializeToString,
            wallet__pb2.GetValidatorAddressResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNewAddress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Wallet/GetNewAddress',
            wallet__pb2.GetNewAddressRequest.SerializeToString,
            wallet__pb2.GetNewAddressResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAddressHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Wallet/GetAddressHistory',
            wallet__pb2.GetAddressHistoryRequest.SerializeToString,
            wallet__pb2.GetAddressHistoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SignMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Wallet/SignMessage',
            wallet__pb2.SignMessageRequest.SerializeToString,
            wallet__pb2.SignMessageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTotalStake(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Wallet/GetTotalStake',
            wallet__pb2.GetTotalStakeRequest.SerializeToString,
            wallet__pb2.GetTotalStakeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAddressInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Wallet/GetAddressInfo',
            wallet__pb2.GetAddressInfoRequest.SerializeToString,
            wallet__pb2.GetAddressInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAddressLabel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Wallet/SetAddressLabel',
            wallet__pb2.SetLabelRequest.SerializeToString,
            wallet__pb2.SetLabelResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListWallet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Wallet/ListWallet',
            wallet__pb2.ListWalletRequest.SerializeToString,
            wallet__pb2.ListWalletResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetWalletInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Wallet/GetWalletInfo',
            wallet__pb2.GetWalletInfoRequest.SerializeToString,
            wallet__pb2.GetWalletInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAddress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/pactus.Wallet/ListAddress',
            wallet__pb2.ListAddressRequest.SerializeToString,
            wallet__pb2.ListAddressResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import transaction_pb2 as _transaction_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BlockVerbosity(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    BLOCK_DATA: _ClassVar[BlockVerbosity]
    BLOCK_INFO: _ClassVar[BlockVerbosity]
    BLOCK_TRANSACTIONS: _ClassVar[BlockVerbosity]

class VoteType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    VOTE_UNKNOWN: _ClassVar[VoteType]
    VOTE_PREPARE: _ClassVar[VoteType]
    VOTE_PRECOMMIT: _ClassVar[VoteType]
    VOTE_CHANGE_PROPOSER: _ClassVar[VoteType]
BLOCK_DATA: BlockVerbosity
BLOCK_INFO: BlockVerbosity
BLOCK_TRANSACTIONS: BlockVerbosity
VOTE_UNKNOWN: VoteType
VOTE_PREPARE: VoteType
VOTE_PRECOMMIT: VoteType
VOTE_CHANGE_PROPOSER: VoteType

class GetAccountRequest(_message.Message):
    __slots__ = ("address",)
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: str
    def __init__(self, address: _Optional[str] = ...) -> None: ...

class GetAccountResponse(_message.Message):
    __slots__ = ("account",)
    ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    account: AccountInfo
    def __init__(self, account: _Optional[_Union[AccountInfo, _Mapping]] = ...) -> None: ...

class GetValidatorAddressesRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetValidatorAddressesResponse(_message.Message):
    __slots__ = ("addresses",)
    ADDRESSES_FIELD_NUMBER: _ClassVar[int]
    addresses: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, addresses: _Optional[_Iterable[str]] = ...) -> None: ...

class GetValidatorRequest(_message.Message):
    __slots__ = ("address",)
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: str
    def __init__(self, address: _Optional[str] = ...) -> None: ...

class GetValidatorByNumberRequest(_message.Message):
    __slots__ = ("number",)
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    number: int
    def __init__(self, number: _Optional[int] = ...) -> None: ...

class GetValidatorResponse(_message.Message):
    __slots__ = ("validator",)
    VALIDATOR_FIELD_NUMBER: _ClassVar[int]
    validator: ValidatorInfo
    def __init__(self, validator: _Optional[_Union[ValidatorInfo, _Mapping]] = ...) -> None: ...

class GetPublicKeyRequest(_message.Message):
    __slots__ = ("address",)
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: str
    def __init__(self, address: _Optional[str] = ...) -> None: ...

class GetPublicKeyResponse(_message.Message):
    __slots__ = ("public_key",)
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    public_key: str
    def __init__(self, public_key: _Optional[str] = ...) -> None: ...

class GetBlockRequest(_message.Message):
    __slots__ = ("height", "verbosity")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    VERBOSITY_FIELD_NUMBER: _ClassVar[int]
    height: int
    verbosity: BlockVerbosity
    def __init__(self, height: _Optional[int] = ..., verbosity: _Optional[_Union[BlockVerbosity, str]] = ...) -> None: ...

class GetBlockResponse(_message.Message):
    __slots__ = ("height", "hash", "data", "block_time", "header", "prev_cert", "txs")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    BLOCK_TIME_FIELD_NUMBER: _ClassVar[int]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    PREV_CERT_FIELD_NUMBER: _ClassVar[int]
    TXS_FIELD_NUMBER: _ClassVar[int]
    height: int
    hash: str
    data: str
    block_time: int
    header: BlockHeaderInfo
    prev_cert: CertificateInfo
    txs: _containers.RepeatedCompositeFieldContainer[_transaction_pb2.TransactionInfo]
    def __init__(self, height: _Optional[int] = ..., hash: _Optional[str] = ..., data: _Optional[str] = ..., block_time: _Optional[int] = ..., header: _Optional[_Union[BlockHeaderInfo, _Mapping]] = ..., prev_cert: _Optional[_Union[CertificateInfo, _Mapping]] = ..., txs: _Optional[_Iterable[_Union[_transaction_pb2.TransactionInfo, _Mapping]]] = ...) -> None: ...

class GetBlockHashRequest(_message.Message):
    __slots__ = ("height",)
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    height: int
    def __init__(self, height: _Optional[int] = ...) -> None: ...

class GetBlockHashResponse(_message.Message):
    __slots__ = ("hash",)
    HASH_FIELD_NUMBER: _ClassVar[int]
    hash: str
    def __init__(self, hash: _Optional[str] = ...) -> None: ...

class GetBlockHeightRequest(_message.Message):
    __slots__ = ("hash",)
    HASH_FIELD_NUMBER: _ClassVar[int]
    hash: str
    def __init__(self, hash: _Optional[str] = ...) -> None: ...

class GetBlockHeightResponse(_message.Message):
    __slots__ = ("height",)
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    height: int
    def __init__(self, height: _Optional[int] = ...) -> None: ...

class GetBlockchainInfoRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetBlockchainInfoResponse(_message.Message):
    __slots__ = ("last_block_height", "last_block_hash", "total_accounts", "total_validators", "total_power", "committee_power", "committee_validators", "is_pruned", "pruning_height", "last_block_time")
    LAST_BLOCK_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    LAST_BLOCK_HASH_FIELD_NUMBER: _ClassVar[int]
    TOTAL_ACCOUNTS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_POWER_FIELD_NUMBER: _ClassVar[int]
    COMMITTEE_POWER_FIELD_NUMBER: _ClassVar[int]
    COMMITTEE_VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    IS_PRUNED_FIELD_NUMBER: _ClassVar[int]
    PRUNING_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    LAST_BLOCK_TIME_FIELD_NUMBER: _ClassVar[int]
    last_block_height: int
    last_block_hash: str
    total_accounts: int
    total_validators: int
    total_power: int
    committee_power: int
    committee_validators: _containers.RepeatedCompositeFieldContainer[ValidatorInfo]
    is_pruned: bool
    pruning_height: int
    last_block_time: int
    def __init__(self, last_block_height: _Optional[int] = ..., last_block_hash: _Optional[str] = ..., total_accounts: _Optional[int] = ..., total_validators: _Optional[int] = ..., total_power: _Optional[int] = ..., committee_power: _Optional[int] = ..., committee_validators: _Optional[_Iterable[_Union[ValidatorInfo, _Mapping]]] = ..., is_pruned: bool = ..., pruning_height: _Optional[int] = ..., last_block_time: _Optional[int] = ...) -> None: ...

class GetConsensusInfoRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetConsensusInfoResponse(_message.Message):
    __slots__ = ("proposal", "instances")
    PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    INSTANCES_FIELD_NUMBER: _ClassVar[int]
    proposal: ProposalInfo
    instances: _containers.RepeatedCompositeFieldContainer[ConsensusInfo]
    def __init__(self, proposal: _Optional[_Union[ProposalInfo, _Mapping]] = ..., instances: _Optional[_Iterable[_Union[ConsensusInfo, _Mapping]]] = ...) -> None: ...

class GetTxPoolContentRequest(_message.Message):
    __slots__ = ("payload_type",)
    PAYLOAD_TYPE_FIELD_NUMBER: _ClassVar[int]
    payload_type: _transaction_pb2.PayloadType
    def __init__(self, payload_type: _Optional[_Union[_transaction_pb2.PayloadType, str]] = ...) -> None: ...

class GetTxPoolContentResponse(_message.Message):
    __slots__ = ("txs",)
    TXS_FIELD_NUMBER: _ClassVar[int]
    txs: _containers.RepeatedCompositeFieldContainer[_transaction_pb2.TransactionInfo]
    def __init__(self, txs: _Optional[_Iterable[_Union[_transaction_pb2.TransactionInfo, _Mapping]]] = ...) -> None: ...

class ValidatorInfo(_message.Message):
    __slots__ = ("hash", "data", "public_key", "number", "stake", "last_bonding_height", "last_sortition_height", "unbonding_height", "address", "availability_score")
    HASH_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    STAKE_FIELD_NUMBER: _ClassVar[int]
    LAST_BONDING_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    LAST_SORTITION_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    UNBONDING_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    AVAILABILITY_SCORE_FIELD_NUMBER: _ClassVar[int]
    hash: str
    data: str
    public_key: str
    number: int
    stake: int
    last_bonding_height: int
    last_sortition_height: int
    unbonding_height: int
    address: str
    availability_score: float
    def __init__(self, hash: _Optional[str] = ..., data: _Optional[str] = ..., public_key: _Optional[str] = ..., number: _Optional[int] = ..., stake: _Optional[int] = ..., last_bonding_height: _Optional[int] = ..., last_sortition_height: _Optional[int] = ..., unbonding_height: _Optional[int] = ..., address: _Optional[str] = ..., availability_score: _Optional[float] = ...) -> None: ...

class AccountInfo(_message.Message):
    __slots__ = ("hash", "data", "number", "balance", "address")
    HASH_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    BALANCE_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    hash: str
    data: str
    number: int
    balance: int
    address: str
    def __init__(self, hash: _Optional[str] = ..., data: _Optional[str] = ..., number: _Optional[int] = ..., balance: _Optional[int] = ..., address: _Optional[str] = ...) -> None: ...

class BlockHeaderInfo(_message.Message):
    __slots__ = ("version", "prev_block_hash", "state_root", "sortition_seed", "proposer_address")
    VERSION_FIELD_NUMBER: _ClassVar[int]
    PREV_BLOCK_HASH_FIELD_NUMBER: _ClassVar[int]
    STATE_ROOT_FIELD_NUMBER: _ClassVar[int]
    SORTITION_SEED_FIELD_NUMBER: _ClassVar[int]
    PROPOSER_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    version: int
    prev_block_hash: str
    state_root: str
    sortition_seed: str
    proposer_address: str
    def __init__(self, version: _Optional[int] = ..., prev_block_hash: _Optional[str] = ..., state_root: _Optional[str] = ..., sortition_seed: _Optional[str] = ..., proposer_address: _Optional[str] = ...) -> None: ...

class CertificateInfo(_message.Message):
    __slots__ = ("hash", "round", "committers", "absentees", "signature")
    HASH_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    COMMITTERS_FIELD_NUMBER: _ClassVar[int]
    ABSENTEES_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    hash: str
    round: int
    committers: _containers.RepeatedScalarFieldContainer[int]
    absentees: _containers.RepeatedScalarFieldContainer[int]
    signature: str
    def __init__(self, hash: _Optional[str] = ..., round: _Optional[int] = ..., committers: _Optional[_Iterable[int]] = ..., absentees: _Optional[_Iterable[int]] = ..., signature: _Optional[str] = ...) -> None: ...

class VoteInfo(_message.Message):
    __slots__ = ("type", "voter", "block_hash", "round", "cp_round", "cp_value")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    VOTER_FIELD_NUMBER: _ClassVar[int]
    BLOCK_HASH_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    CP_ROUND_FIELD_NUMBER: _ClassVar[int]
    CP_VALUE_FIELD_NUMBER: _ClassVar[int]
    type: VoteType
    voter: str
    block_hash: str
    round: int
    cp_round: int
    cp_value: int
    def __init__(self, type: _Optional[_Union[VoteType, str]] = ..., voter: _Optional[str] = ..., block_hash: _Optional[str] = ..., round: _Optional[int] = ..., cp_round: _Optional[int] = ..., cp_value: _Optional[int] = ...) -> None: ...

class ConsensusInfo(_message.Message):
    __slots__ = ("address", "active", "height", "round", "votes")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    VOTES_FIELD_NUMBER: _ClassVar[int]
    address: str
    active: bool
    height: int
    round: int
    votes: _containers.RepeatedCompositeFieldContainer[VoteInfo]
    def __init__(self, address: _Optional[str] = ..., active: bool = ..., height: _Optional[int] = ..., round: _Optional[int] = ..., votes: _Optional[_Iterable[_Union[VoteInfo, _Mapping]]] = ...) -> None: ...

class ProposalInfo(_message.Message):
    __slots__ = ("height", "round", "block_data", "signature")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    BLOCK_DATA_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    height: int
    round: int
    block_data: str
    signature: str
    def __init__(self, height: _Optional[int] = ..., round: _Optional[int] = ..., block_data: _Optional[str] = ..., signature: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: transaction.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11transaction.proto\x12\x06pactus\"c\n\x15GetTransactionRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12:\n\tverbosity\x18\x02 \x01(\x0e\x32\x1c.pactus.TransactionVerbosityR\tverbosity\"\x95\x01\n\x16GetTransactionResponse\x12!\n\x0c\x62lock_height\x18\x01 \x01(\rR\x0b\x62lockHeight\x12\x1d\n\nblock_time\x18\x02 \x01(\rR\tblockTime\x12\x39\n\x0btransaction\x18\x03 \x01(\x0b\x32\x17.pactus.TransactionInfoR\x0btransaction\"\x88\x01\n\x13\x43\x61lculateFeeRequest\x12\x16\n\x06\x61mount\x18\x01 \x01(\x03R\x06\x61mount\x12\x36\n\x0cpayload_type\x18\x02 \x01(\x0e\x32\x13.pactus.PayloadTypeR\x0bpayloadType\x12!\n\x0c\x66ixed_amount\x18\x03 \x01(\x08R\x0b\x66ixedAmount\"@\n\x14\x43\x61lculateFeeResponse\x12\x16\n\x06\x61mount\x18\x01 \x01(\x03R\x06\x61mount\x12\x10\n\x03\x66\x65\x65\x18\x02 \x01(\x03R\x03\x66\x65\x65\"S\n\x1b\x42roadcastTransactionRequest\x12\x34\n\x16signed_raw_transaction\x18\x01 \x01(\tR\x14signedRawTransaction\".\n\x1c\x42roadcastTransactionResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\xb1\x01\n GetRawTransferTransactionRequest\x12\x1b\n\tlock_time\x18\x01 \x01(\rR\x08lockTime\x12\x16\n\x06sender\x18\x02 \x01(\tR\x06sender\x12\x1a\n\x08receiver\x18\x03 \x01(\tR\x08receiver\x12\x16\n\x06\x61mount\x18\x04 \x01(\x03R\x06\x61mount\x12\x10\n\x03\x66\x65\x65\x18\x05 \x01(\x03R\x03\x66\x65\x65\x12\x12\n\x04memo\x18\x06 \x01(\tR\x04memo\"\xca\x01\n\x1cGetRawBondTransactionRequest\x12\x1b\n\tlock_time\x18\x01 \x01(\rR\x08lockTime\x12\x16\n\x06sender\x18\x02 \x01(\tR\x06sender\x12\x1a\n\x08receiver\x18\x03 \x01(\tR\x08receiver\x12\x14\n\x05stake\x18\x04 \x01(\x03R\x05stake\x12\x1d\n\npublic_key\x18\x05 \x01(\tR\tpublicKey\x12\x10\n\x03\x66\x65\x65\x18\x06 \x01(\x03R\x03\x66\x65\x65\x12\x12\n\x04memo\x18\x07 \x01(\tR\x04memo\"~\n\x1eGetRawUnbondTransactionRequest\x12\x1b\n\tlock_time\x18\x01 \x01(\rR\x08lockTime\x12+\n\x11validator_address\x18\x03 \x01(\tR\x10validatorAddress\x12\x12\n\x04memo\x18\x04 \x01(\tR\x04memo\"\xd3\x01\n GetRawWithdrawTransactionRequest\x12\x1b\n\tlock_time\x18\x01 \x01(\rR\x08lockTime\x12+\n\x11validator_address\x18\x02 \x01(\tR\x10validatorAddress\x12\'\n\x0f\x61\x63\x63ount_address\x18\x03 \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x16\n\x06\x61mount\x18\x04 \x01(\x03R\x06\x61mount\x12\x10\n\x03\x66\x65\x65\x18\x05 \x01(\x03R\x03\x66\x65\x65\x12\x12\n\x04memo\x18\x06 \x01(\tR\x04memo\"T\n\x19GetRawTransactionResponse\x12\'\n\x0fraw_transaction\x18\x01 \x01(\tR\x0erawTransaction\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\"]\n\x0fPayloadTransfer\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x1a\n\x08receiver\x18\x02 \x01(\tR\x08receiver\x12\x16\n\x06\x61mount\x18\x03 \x01(\x03R\x06\x61mount\"v\n\x0bPayloadBond\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x1a\n\x08receiver\x18\x02 \x01(\tR\x08receiver\x12\x14\n\x05stake\x18\x03 \x01(\x03R\x05stake\x12\x1d\n\npublic_key\x18\x04 \x01(\tR\tpublicKey\"B\n\x10PayloadSortition\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x14\n\x05proof\x18\x02 \x01(\tR\x05proof\"-\n\rPayloadUnbond\x12\x1c\n\tvalidator\x18\x01 \x01(\tR\tvalidator\"\x7f\n\x0fPayloadWithdraw\x12+\n\x11validator_address\x18\x01 \x01(\tR\x10validatorAddress\x12\'\n\x0f\x61\x63\x63ount_address\x18\x02 \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x16\n\x06\x61mount\x18\x03 \x01(\x03R\x06\x61mount\"\xac\x04\n\x0fTransactionInfo\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\tR\x04\x64\x61ta\x12\x18\n\x07version\x18\x03 \x01(\x05R\x07version\x12\x1b\n\tlock_time\x18\x04 \x01(\rR\x08lockTime\x12\x14\n\x05value\x18\x05 \x01(\x03R\x05value\x12\x10\n\x03\x66\x65\x65\x18\x06 \x01(\x03R\x03\x66\x65\x65\x12\x36\n\x0cpayload_type\x18\x07 \x01(\x0e\x32\x13.pactus.PayloadTypeR\x0bpayloadType\x12\x35\n\x08transfer\x18\x1e \x01(\x0b\x32\x17.pactus.PayloadTransferH\x00R\x08transfer\x12)\n\x04\x62ond\x18\x1f \x01(\x0b\x32\x13.pactus.PayloadBondH\x00R\x04\x62ond\x12\x38\n\tsortition\x18  \x01(\x0b\x32\x18.pactus.PayloadSortitionH\x00R\tsortition\x12/\n\x06unbond\x18! \x01(\x0b\x32\x15.pactus.PayloadUnbondH\x00R\x06unbond\x12\x35\n\x08withdraw\x18\" \x01(\x0b\x32\x17.pactus.PayloadWithdrawH\x00R\x08withdraw\x12\x12\n\x04memo\x18\x08 \x01(\tR\x04memo\x12\x1d\n\npublic_key\x18\t \x01(\tR\tpublicKey\x12\x1c\n\tsignature\x18\n \x01(\tR\tsignatureB\t\n\x07payload*\x83\x01\n\x0bPayloadType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x14\n\x10TRANSFER_PAYLOAD\x10\x01\x12\x10\n\x0c\x42OND_PAYLOAD\x10\x02\x12\x15\n\x11SORTITION_PAYLOAD\x10\x03\x12\x12\n\x0eUNBOND_PAYLOAD\x10\x04\x12\x14\n\x10WITHDRAW_PAYLOAD\x10\x05*B\n\x14TransactionVerbosity\x12\x14\n\x10TRANSACTION_DATA\x10\x00\x12\x14\n\x10TRANSACTION_INFO\x10\x01\x32\xa8\x05\n\x0bTransaction\x12O\n\x0eGetTransaction\x12\x1d.pactus.GetTransactionRequest\x1a\x1e.pactus.GetTransactionResponse\x12I\n\x0c\x43\x61lculateFee\x12\x1b.pactus.CalculateFeeRequest\x1a\x1c.pactus.CalculateFeeResponse\x12\x61\n\x14\x42roadcastTransaction\x12#.pactus.BroadcastTransactionRequest\x1a$.pactus.BroadcastTransactionResponse\x12h\n\x19GetRawTransferTransaction\x12(.pactus.GetRawTransferTransactionRequest\x1a!.pactus.GetRawTransactionResponse\x12`\n\x15GetRawBondTransaction\x12$.pactus.GetRawBondTransactionRequest\x1a!.pactus.GetRawTransactionResponse\x12\x64\n\x17GetRawUnbondTransaction\x12&.pactus.GetRawUnbondTransactionRequest\x1a!.pactus.GetRawTransactionResponse\x12h\n\x19GetRawWithdrawTransaction\x12(.pactus.GetRawWithdrawTransactionRequest\x1a!.pactus.GetRawTransactionResponseBF\n\x12pactus.transactionZ0github.com/pactus-project/pactus/www/grpc/pactusb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'transaction_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022pactus.transactionZ0github.com/pactus-project/pactus/www/grpc/pactus'
  _PAYLOADTYPE._serialized_start=2452
  _PAYLOADTYPE._serialized_end=2583
  _TRANSACTIONVERBOSITY._serialized_start=2585
  _TRANSACTIONVERBOSITY._serialized_end=2651
  _GETTRANSACTIONREQUEST._serialized_start=29
  _GETTRANSACTIONREQUEST._serialized_end=128
  _GETTRANSACTIONRESPONSE._serialized_start=131
  _GETTRANSACTIONRESPONSE._serialized_end=280
  _CALCULATEFEEREQUEST._serialized_start=283
  _CALCULATEFEEREQUEST._serialized_end=419
  _CALCULATEFEERESPONSE._serialized_start=421
  _CALCULATEFEERESPONSE._serialized_end=485
  _BROADCASTTRANSACTIONREQUEST._serialized_start=487
  _BROADCASTTRANSACTIONREQUEST._serialized_end=570
  _BROADCASTTRANSACTIONRESPONSE._serialized_start=572
  _BROADCASTTRANSACTIONRESPONSE._serialized_end=618
  _GETRAWTRANSFERTRANSACTIONREQUEST._serialized_start=621
  _GETRAWTRANSFERTRANSACTIONREQUEST._serialized_end=798
  _GETRAWBONDTRANSACTIONREQUEST._serialized_start=801
  _GETRAWBONDTRANSACTIONREQUEST._serialized_end=1003
  _GETRAWUNBONDTRANSACTIONREQUEST._serialized_start=1005
  _GETRAWUNBONDTRANSACTIONREQUEST._serialized_end=1131
  _GETRAWWITHDRAWTRANSACTIONREQUEST._serialized_start=1134
  _GETRAWWITHDRAWTRANSACTIONREQUEST._serialized_end=1345
  _GETRAWTRANSACTIONRESPONSE._serialized_start=1347
  _GETRAWTRANSACTIONRESPONSE._serialized_end=1431
  _PAYLOADTRANSFER._serialized_start=1433
  _PAYLOADTRANSFER._serialized_end=1526
  _PAYLOADBOND._serialized_start=1528
  _PAYLOADBOND._serialized_end=1646
  _PAYLOADSORTITION._serialized_start=1648
  _PAYLOADSORTITION._serialized_end=1714
  _PAYLOADUNBOND._serialized_start=1716
  _PAYLOADUNBOND._serialized_end=1761
  _PAYLOADWITHDRAW._serialized_start=1763
  _PAYLOADWITHDRAW._serialized_end=1890
  _TRANSACTIONINFO._serialized_start=1893
  _TRANSACTIONINFO._serialized_end=2449
  _TRANSACTION._serialized_start=2654
  _TRANSACTION._serialized_end=3334
# @@protoc_insertion_point(module_scope)



import transaction_pb2 as _transaction_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AddressType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ADDRESS_TYPE_TREASURY: _ClassVar[AddressType]
    ADDRESS_TYPE_VALIDATOR: _ClassVar[AddressType]
    ADDRESS_TYPE_BLS_ACCOUNT: _ClassVar[AddressType]
    ADDRESS_TYPE_ED25519_ACCOUNT: _ClassVar[AddressType]
ADDRESS_TYPE_TREASURY: AddressType
ADDRESS_TYPE_VALIDATOR: AddressType
ADDRESS_TYPE_BLS_ACCOUNT: AddressType
ADDRESS_TYPE_ED25519_ACCOUNT: AddressType

class AddressInfo(_message.Message):
    __slots__ = ("address", "public_key", "label", "path")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    LABEL_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    address: str
    public_key: str
    label: str
    path: str
    def __init__(self, address: _Optional[str] = ..., public_key: _Optional[str] = ..., label: _Optional[str] = ..., path: _Optional[str] = ...) -> None: ...

class HistoryInfo(_message.Message):
    __slots__ = ("transaction_id", "time", "payload_type", "description", "amount")
    TRANSACTION_ID_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_TYPE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    transaction_id: str
    time: int
    payload_type: str
    description: str
    amount: int
    def __init__(self, transaction_id: _Optional[str] = ..., time: _Optional[int] = ..., payload_type: _Optional[str] = ..., description: _Optional[str] = ..., amount: _Optional[int] = ...) -> None: ...

class GetAddressHistoryRequest(_message.Message):
    __slots__ = ("wallet_name", "address")
    WALLET_NAME_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    wallet_name: str
    address: str
    def __init__(self, wallet_name: _Optional[str] = ..., address: _Optional[str] = ...) -> None: ...

class GetAddressHistoryResponse(_message.Message):
    __slots__ = ("history_info",)
    HISTORY_INFO_FIELD_NUMBER: _ClassVar[int]
    history_info: _containers.RepeatedCompositeFieldContainer[HistoryInfo]
    def __init__(self, history_info: _Optional[_Iterable[_Union[HistoryInfo, _Mapping]]] = ...) -> None: ...

class GetNewAddressRequest(_message.Message):
    __slots__ = ("wallet_name", "address_type", "label", "password")
    WALLET_NAME_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_TYPE_FIELD_NUMBER: _ClassVar[int]
    LABEL_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    wallet_name: str
    address_type: AddressType
    label: str
    password: str
    def __init__(self, wallet_name: _Optional[str] = ..., address_type: _Optional[_Union[AddressType, str]] = ..., label: _Optional[str] = ..., password: _Optional[str] = ...) -> None: ...

class GetNewAddressResponse(_message.Message):
    __slots__ = ("wallet_name", "address_info")
    WALLET_NAME_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_INFO_FIELD_NUMBER: _ClassVar[int]
    wallet_name: str
    address_info: AddressInfo
    def __init__(self, wallet_name: _Optional[str] = ..., address_info: _Optional[_Union[AddressInfo, _Mapping]] = ...) -> None: ...

class RestoreWalletRequest(_message.Message):
    __slots__ = ("wallet_name", "mnemonic", "password")
    WALLET_NAME_FIELD_NUMBER: _ClassVar[int]
    MNEMONIC_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    wallet_name: str
    mnemonic: str
    password: str
    def __init__(self, wallet_name: _Optional[str] = ..., mnemonic: _Optional[str] = ..., password: _Optional[str] = ...) -> None: ...

class RestoreWalletResponse(_message.Message):
    __slots__ = ("wallet_name",)
    WALLET_NAME_FIELD_NUMBER: _ClassVar[int]
    wallet_name: str
    def __init__(self, wallet_name: _Optional[str] = ...) -> None: ...

class CreateWalletRequest(_message.Message):
    __slots__ = ("wallet_name", "password")
    WALLET_NAME_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    wallet_name: str
    password: str
    def __init__(self, wallet_name: _Optional[str] = ..., password: _Optional[str] = ...) -> None: ...

class CreateWalletResponse(_message.Message):
    __slots__ = ("mnemonic",)
    MNEMONIC_FIELD_NUMBER: _ClassVar[int]
    mnemonic: str
    def __init__(self, mnemonic: _Optional[str] = ...) -> None: ...

class LoadWalletRequest(_message.Message):
    __slots__ = ("wallet_name",)
    WALLET_NAME_FIELD_NUMBER: _ClassVar[int]
    wallet_name: str
    def __init__(self, wallet_name: _Optional[str] = ...) -> None: ...

class LoadWalletResponse(_message.Message):
    __slots__ = ("wallet_name",)
    WALLET_NAME_FIELD_NUMBER: _ClassVar[int]
    wallet_name: str
    def __init__(self, wallet_name: _Optional[str] = ...) -> None: ...

class UnloadWalletRequest(_message.Message):
    __slots__ = ("wallet_name",)
    WALLET_NAME_FIELD_NUMBER: _ClassVar[int]
    wallet_name: str
    def __init__(self, wallet_name: _Optional[str] = ...) -> None: ...

class UnloadWalletResponse(_message.Message):
    __slots__ = ("wallet_name",)
    WALLET_NAME_FIELD_NUMBER: _ClassVar[int]
    wallet_name: str
    def __init__(self, wallet_name: _Optional[str] = ...) -> None: ...

class GetValidatorAddressRequest(_message.Message):
    __slots__ = ("public_key",)
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    public_key: str
    def __init__(self, public_key: _Optional[str] = ...) -> None: ...

class GetValidatorAddressResponse(_message.Message):
    __slots__ = ("address",)
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: str
    def __init__(self, address: _Optional[str] = ...) -> None: ...

class SignRawTransactionRequest(_message.Message):
    __slots__ = ("wallet_name", "raw_transaction", "password")
    WALLET_NAME_FIELD_NUMBER: _ClassVar[int]
    RAW_TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    wallet_name: str
    raw_transaction: str
    password: str
    def __init__(self, wallet_name: _Optional[str] = ..., raw_transaction: _Optional[str] = ..., password: _Optional[str] = ...) -> None: ...

class SignRawTransactionResponse(_message.Message):
    __slots__ = ("transaction_id", "signed_raw_transaction")
    TRANSACTION_ID_FIELD_NUMBER: _ClassVar[int]
    SIGNED_RAW_TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    transaction_id: str
    signed_raw_transaction: str
    def __init__(self, transaction_id: _Optional[str] = ..., signed_raw_transaction: _Optional[str] = ...) -> None: ...

class GetTotalBalanceRequest(_message.Message):
    __slots__ = ("wallet_name",)
    WALLET_NAME_FIELD_NUMBER: _ClassVar[int]
    wallet_name: str
    def __init__(self, wallet_name: _Optional[str] = ...) -> None: ...

class GetTotalBalanceResponse(_message.Message):
    __slots__ = ("wallet_name", "total_balance")
    WALLET_NAME_FIELD_NUMBER: _ClassVar[int]
    TOTAL_BALANCE_FIELD_NUMBER: _ClassVar[int]
    wallet_name: str
    total_balance: int
    def __init__(self, wallet_name: _Optional[str] = ..., total_balance: _Optional[int] = ...) -> None: ...

class SignMessageRequest(_message.Message):
    __slots__ = ("wallet_name", "password", "address", "message")
    WALLET_NAME_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    wallet_name: str
    password: str
    address: str
    message: str
    def __init__(self, wallet_name: _Optional[str] = ..., password: _Optional[str] = ..., address: _Optional[str] = ..., message: _Optional[str] = ...) -> None: ...

class SignMessageResponse(_message.Message):
    __slots__ = ("signature",)
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    signature: str
    def __init__(self, signature: _Optional[str] = ...) -> None: ...

class GetTotalStakeRequest(_message.Message):
    __slots__ = ("wallet_name",)
    WALLET_NAME_FIELD_NUMBER: _ClassVar[int]
    wallet_name: str
    def __init__(self, wallet_name: _Optional[str] = ...) -> None: ...

class GetTotalStakeResponse(_message.Message):
    __slots__ = ("total_stake", "wallet_name")
    TOTAL_STAKE_FIELD_NUMBER: _ClassVar[int]
    WALLET_NAME_FIELD_NUMBER: _ClassVar[int]
    total_stake: int
    wallet_name: str
    def __init__(self, total_stake: _Optional[int] = ..., wallet_name: _Optional[str] = ...) -> None: ...

class GetAddressInfoRequest(_message.Message):
    __slots__ = ("wallet_name", "address")
    WALLET_NAME_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    wallet_name: str
    address: str
    def __init__(self, wallet_name: _Optional[str] = ..., address: _Optional[str] = ...) -> None: ...

class GetAddressInfoResponse(_message.Message):
    __slots__ = ("address", "label", "public_key", "path", "wallet_name")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    LABEL_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    WALLET_NAME_FIELD_NUMBER: _ClassVar[int]
    address: str
    label: str
    public_key: str
    path: str
    wallet_name: str
    def __init__(self, address: _Optional[str] = ..., label: _Optional[str] = ..., public_key: _Optional[str] = ..., path: _Optional[str] = ..., wallet_name: _Optional[str] = ...) -> None: ...

class SetLabelRequest(_message.Message):
    __slots__ = ("wallet_name", "password", "address", "label")
    WALLET_NAME_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    LABEL_FIELD_NUMBER: _ClassVar[int]
    wallet_name: str
    password: str
    address: str
    label: str
    def __init__(self, wallet_name: _Optional[str] = ..., password: _Optional[str] = ..., address: _Optional[str] = ..., label: _Optional[str] = ...) -> None: ...

class SetLabelResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListWalletRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListWalletResponse(_message.Message):
    __slots__ = ("wallets",)
    WALLETS_FIELD_NUMBER: _ClassVar[int]
    wallets: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, wallets: _Optional[_Iterable[str]] = ...) -> None: ...

class GetWalletInfoRequest(_message.Message):
    __slots__ = ("wallet_name",)
    WALLET_NAME_FIELD_NUMBER: _ClassVar[int]
    wallet_name: str
    def __init__(self, wallet_name: _Optional[str] = ...) -> None: ...

class GetWalletInfoResponse(_message.Message):
    __slots__ = ("wallet_name", "version", "network", "encrypted", "uuid", "created_at")
    WALLET_NAME_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    NETWORK_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTED_FIELD_NUMBER: _ClassVar[int]
    UUID_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    wallet_name: str
    version: int
    network: str
    encrypted: bool
    uuid: str
    created_at: int
    def __init__(self, wallet_name: _Optional[str] = ..., version: _Optional[int] = ..., network: _Optional[str] = ..., encrypted: bool = ..., uuid: _Optional[str] = ..., created_at: _Optional[int] = ...) -> None: ...

class ListAddressRequest(_message.Message):
    __slots__ = ("wallet_name",)
    WALLET_NAME_FIELD_NUMBER: _ClassVar[int]
    wallet_name: str
    def __init__(self, wallet_name: _Optional[str] = ...) -> None: ...

class ListAddressResponse(_message.Message):
    __slots__ = ("data",)
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: _containers.RepeatedCompositeFieldContainer[AddressInfo]
    def __init__(self, data: _Optional[_Iterable[_Union[AddressInfo, _Mapping]]] = ...) -> None: ...
